
# Base all directories relative to the location of the ParaViewConfig.cmake file.
GET_FILENAME_COMPONENT(ParaView_INSTALL_PREFIX "${ParaView_DIR}/../.." ABSOLUTE)

# Version information for ParaView
SET(PARAVIEW_VERSION_MAJOR "3")
SET(PARAVIEW_VERSION_MINOR "14")
SET(PARAVIEW_VERSION_PATCH "1")
SET(PARAVIEW_VERSION_FULL    "3.14.1")

# Locations for the source and binary dirs.
# I am not sure ParaView_SOURCE_DIR should be exported since it won't be
# available for development-install
SET(ParaView_CMAKE_DIR "${ParaView_INSTALL_PREFIX}/lib/paraview/CMake")
SET(ParaView_BINARY_DIR "${ParaView_INSTALL_PREFIX}/bin")

# Some core ParaView settings.
SET(PARAVIEW_BUILD_SHARED_LIBS "ON")
SET(PARAVIEW_ENABLE_PYTHON "ON")
SET(PARAVIEW_BUILD_QT_GUI "ON")

IF (PARAVIEW_ENABLE_PYTHON)
  SET (PARAVIEW_PYTHON_INCLUDE_DIR "/usr/include/python2.7")
ENDIF()

SET(PARAVIEW_USE_FILE "${ParaView_INSTALL_PREFIX}/lib/paraview/CMake/ParaViewUse.cmake")
SET(PARAVIEW_VTK_DIR "${ParaView_INSTALL_PREFIX}/lib/paraview")
SET(PARAVIEW_QT_QMAKE_EXECUTABLE "")
SET(ParaView_QT_DIR "${ParaView_INSTALL_PREFIX}/include/paraview/Qt")

# Locate to extra CMake modules.
#SET(PARAVIEW_CMAKE_EXTENSIONS "")

SET(VTK_WRAP_ClientServer_EXE "${ParaView_INSTALL_PREFIX}/bin/vtkWrapClientServer")
SET(PARAVIEW_INCLUDE_DIRS "${ParaView_INSTALL_PREFIX}/include/paraview")
SET(PARAVIEW_PROTOBUF_INCLUDE_DIR "/builddir/build/BUILD/ParaView-3.14.1-Source/Utilities/protobuf/src")
SET(PARAVIEW_LIBRARY_DIRS "${ParaView_INSTALL_PREFIX}/lib/paraview")

SET(PARAVIEW_GUI_INCLUDE_DIRS "${ParaView_INSTALL_PREFIX}/include/paraview")
SET(PARAVIEW_KWSYS_INCLUDE_DIRS "${ParaView_INSTALL_PREFIX}/include/paraview")

# Path to various paraview executables needed for testing.
SET(PARAVIEW_BATCH_EXECUTABLE "${ParaView_INSTALL_PREFIX}/bin/pvbatch")
SET(PARAVIEW_PYTHON_EXECUTABLE "${ParaView_INSTALL_PREFIX}/bin/pvpython")
SET(PARAVIEW_SERVER_EXECUTABLE "${ParaView_INSTALL_PREFIX}/bin/pvserver")
SET(PARAVIEW_DATA_SERVER_EXECUTABLE "${ParaView_INSTALL_PREFIX}/bin/pvdataserver")
SET(PARAVIEW_RENDER_SERVER_EXECUTABLE "${ParaView_INSTALL_PREFIX}/bin/pvrenderserver")
SET(PARAVIEW_SMTESTDRIVER_EXECUTABLE "${ParaView_INSTALL_PREFIX}/bin/smTestDriver")

SET(PARAVIEW_PROCESS_XML_EXECUTABLE "${ParaView_INSTALL_PREFIX}/bin/kwProcessXML")
SET(PARAVIEW_SERVER_MANAGER_RESOURCES_DIRECTORY "${ParaView_INSTALL_PREFIX}/lib/paraview/ParaViewCore/ServerImplementation/Resources")
SET(VTKCS_CONFIG_DIR "${ParaView_INSTALL_PREFIX}/lib/paraview/CMake")

SET(PARAVIEW_HDF5_LIBRARIES "debug;/usr/lib/libhdf5_hl.so;debug;/usr/lib/libhdf5.so;optimized;/usr/lib/libhdf5_hl.so;optimized;/usr/lib/libhdf5.so")

# The ParaView targets file.
IF(NOT PV_INSTALL_EXPORT_NAME AND NOT TARGET vtkPVCommon
   AND EXISTS "${ParaView_INSTALL_PREFIX}/lib/paraview/CMake/ParaViewTargets.cmake")
  INCLUDE("${ParaView_INSTALL_PREFIX}/lib/paraview/CMake/ParaViewTargets.cmake")
ENDIF()

SET(VTK_MAKE_INSTANTIATOR "${ParaView_INSTALL_PREFIX}/lib/paraview/CMake")
SET(VTK_ENCODESTRING_EXE "/builddir/build/BUILD/ParaView-3.14.1-Source/fedora/bin/vtkEncodeString")

# The locations/prefixes where this version of ParaView would be installed.
SET (PARAVIEW_INSTALL_LIB_DIR "lib/paraview")

SET(PARAVIEW_ENABLE_COPROCESSING "OFF")
IF(PARAVIEW_ENABLE_COPROCESSING)
  SET(CoProcessing_DIR "")
ENDIF(PARAVIEW_ENABLE_COPROCESSING)

SET(PARAVIEW_USE_VISITBRIDGE "OFF")
IF(PARAVIEW_USE_VISITBRIDGE)
  SET(VISIT_CMAKE_DIR "${ParaView_INSTALL_PREFIX}/lib/paraview/CMake")
  SET(VISITBRIDGE_USE_FILE "${ParaView_INSTALL_PREFIX}/lib/paraview/CMake/VisItBridgeUse.cmake")
ENDIF(PARAVIEW_USE_VISITBRIDGE)
